betty.extension.gramps.config module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.gramps.config module

Provide configuration for the `betty.extension.Gramps` extension.

class betty.extension.gramps.config.FamilyTreeConfiguration

  Bases: `Configuration`

  Configure a single Gramps family tree.

  __init__(file_path: Path)
  dump() → bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | type[Void]

    Dump this instance to a portable format.

  property file_path: Path | None

    The path to the Gramps family tree file.

  load(dump: bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]) → None

    Load dumped configuration.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump contains invalid configuration.

  update(other: Self) → None

    Update this configuration with the values from `other`.

class betty.extension.gramps.config.FamilyTreeConfigurationSequence

  Bases: `ConfigurationSequence`[`FamilyTreeConfiguration`]

  Configure zero or more Gramps family trees.

  load_item(dump: bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]) → FamilyTreeConfiguration

    Create and load a new item from the given dump, or raise an assertion error.

    Raises:

      betty.assertion.error.AssertionFailed – Raised when the dump is invalid and cannot be loaded.

class betty.extension.gramps.config.GrampsConfiguration

  Bases: `Configuration`

  Provide configuration for the `betty.extension.gramps.Gramps` extension.

  __init__(*, family_trees: Iterable[FamilyTreeConfiguration] | None = None)
  dump() → bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | type[Void]

    Dump this instance to a portable format.

  property family_trees: FamilyTreeConfigurationSequence

    The Gramps family trees to load.

  load(dump: bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]) → None

    Load dumped configuration.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump contains invalid configuration.

  update(other: Self) → None

    Update this configuration with the values from `other`.